@@ -21,7 +21,7 @@ from six.moves import http_client as httplib
 from six.moves.urllib import request as Request
 from six.moves.urllib.error import HTTPError
 from six.moves.urllib.request import HTTPRedirectHandler, HTTPSHandler
-ssl._create_default_https_context = ssl._create_unverified_context
+#ssl._create_default_https_context = ssl._create_unverified_context
 log = logging.getLogger('imc')
 
 
